// Fichier GameStats.java
/**
 * Gère la collecte, la persistance (via SharedPreferences) et l'accès
 * aux statistiques du jeu 2048, pour les modes solo et multijoueur (si applicable).
 */
package legion.muyue.best2048;

import android.annotation.SuppressLint;
import android.content.Context;
import android.content.SharedPreferences;
import java.util.concurrent.TimeUnit;

public class GameStats {

    // --- Constantes pour SharedPreferences ---
    private static final String PREFS_NAME = "Best2048_Prefs";
    private static final String HIGH_SCORE_KEY = "high_score"; // Clé partagée avec Game/MainActivity
    // Clés spécifiques aux statistiques
    private static final String STATS_TOTAL_GAMES_PLAYED = "totalGamesPlayed";
    private static final String STATS_TOTAL_GAMES_STARTED = "totalGamesStarted";
    private static final String STATS_TOTAL_MOVES = "totalMoves";
    private static final String STATS_TOTAL_PLAY_TIME_MS = "totalPlayTimeMs";
    private static final String STATS_TOTAL_MERGES = "totalMerges";
    private static final String STATS_HIGHEST_TILE = "highestTile";
    private static final String STATS_OBJECTIVE_REACHED_COUNT = "numberOfTimesObjectiveReached";
    private static final String STATS_PERFECT_GAMES = "perfectGames";
    private static final String STATS_BEST_WINNING_TIME_MS = "bestWinningTimeMs";
    private static final String STATS_WORST_WINNING_TIME_MS = "worstWinningTimeMs";
    // ... (autres clés stats) ...
    private static final String STATS_MP_GAMES_WON = "multiplayerGamesWon";
    private static final String STATS_MP_GAMES_PLAYED = "multiplayerGamesPlayed";
    private static final String STATS_MP_BEST_WINNING_STREAK = "multiplayerBestWinningStreak";
    private static final String STATS_MP_TOTAL_SCORE = "multiplayerTotalScore";
    private static final String STATS_MP_TOTAL_TIME_MS = "multiplayerTotalTimeMs";
    private static final String STATS_MP_LOSSES = "totalMultiplayerLosses";
    private static final String STATS_MP_HIGH_SCORE = "multiplayerHighScore";


    // --- Champs de Statistiques ---
    // Générales & Solo
    private int totalGamesPlayed;
    private int totalGamesStarted;
    private int totalMoves;
    private long totalPlayTimeMs;
    private int totalMerges;
    private int highestTile;
    private int numberOfTimesObjectiveReached; // Nombre de victoires (>= 2048)
    private int perfectGames; // Concept non défini ici
    private long bestWinningTimeMs;
    private long worstWinningTimeMs;
    private int overallHighScore; // Meilleur score global

    // Partie en cours (non persistées telles quelles)
    private int currentMoves;
    private long currentGameStartTimeMs;
    private int mergesThisGame;

    // Multijoueur
    private int multiplayerGamesWon;
    private int multiplayerGamesPlayed;
    private int multiplayerBestWinningStreak;
    private long multiplayerTotalScore;
    private long multiplayerTotalTimeMs;
    private int totalMultiplayerLosses;
    private int multiplayerHighestScore;

    /** Contexte nécessaire pour accéder aux SharedPreferences. */
    private final Context context;

    /**
     * Constructeur. Initialise l'objet et charge immédiatement les statistiques
     * depuis les SharedPreferences.
     * @param context Contexte de l'application.
     */
    public GameStats(Context context) {
        this.context = context.getApplicationContext(); // Utilise le contexte applicatif
        loadStats();
    }

    // --- Persistance (SharedPreferences) ---

    /**
     * Charge toutes les statistiques persistantes depuis les SharedPreferences.
     * Appelé par le constructeur.
     */
    public void loadStats() {
        SharedPreferences prefs = context.getSharedPreferences(PREFS_NAME, Context.MODE_PRIVATE);
        overallHighScore = prefs.getInt(HIGH_SCORE_KEY, 0);
        totalGamesPlayed = prefs.getInt(STATS_TOTAL_GAMES_PLAYED, 0);
        totalGamesStarted = prefs.getInt(STATS_TOTAL_GAMES_STARTED, 0);
        // ... (chargement de toutes les autres clés persistantes) ...
        totalMoves = prefs.getInt(STATS_TOTAL_MOVES, 0);
        totalPlayTimeMs = prefs.getLong(STATS_TOTAL_PLAY_TIME_MS, 0);
        totalMerges = prefs.getInt(STATS_TOTAL_MERGES, 0);
        highestTile = prefs.getInt(STATS_HIGHEST_TILE, 0);
        numberOfTimesObjectiveReached = prefs.getInt(STATS_OBJECTIVE_REACHED_COUNT, 0);
        perfectGames = prefs.getInt(STATS_PERFECT_GAMES, 0);
        bestWinningTimeMs = prefs.getLong(STATS_BEST_WINNING_TIME_MS, Long.MAX_VALUE); // MAX_VALUE comme défaut pour 'best'
        worstWinningTimeMs = prefs.getLong(STATS_WORST_WINNING_TIME_MS, 0);
        multiplayerGamesWon = prefs.getInt(STATS_MP_GAMES_WON, 0);
        multiplayerGamesPlayed = prefs.getInt(STATS_MP_GAMES_PLAYED, 0);
        multiplayerBestWinningStreak = prefs.getInt(STATS_MP_BEST_WINNING_STREAK, 0);
        multiplayerTotalScore = prefs.getLong(STATS_MP_TOTAL_SCORE, 0);
        multiplayerTotalTimeMs = prefs.getLong(STATS_MP_TOTAL_TIME_MS, 0);
        totalMultiplayerLosses = prefs.getInt(STATS_MP_LOSSES, 0);
        multiplayerHighestScore = prefs.getInt(STATS_MP_HIGH_SCORE, 0);
    }

    /**
     * Sauvegarde toutes les statistiques persistantes dans les SharedPreferences.
     * Appelé typiquement dans `onPause` de l'activité.
     */
    public void saveStats() {
        SharedPreferences prefs = context.getSharedPreferences(PREFS_NAME, Context.MODE_PRIVATE);
        SharedPreferences.Editor editor = prefs.edit();
        editor.putInt(HIGH_SCORE_KEY, overallHighScore); // Sauvegarde le HS global
        editor.putInt(STATS_TOTAL_GAMES_PLAYED, totalGamesPlayed);
        editor.putInt(STATS_TOTAL_GAMES_STARTED, totalGamesStarted);
        // ... (sauvegarde de toutes les autres clés persistantes) ...
        editor.putInt(STATS_TOTAL_MOVES, totalMoves);
        editor.putLong(STATS_TOTAL_PLAY_TIME_MS, totalPlayTimeMs);
        editor.putInt(STATS_TOTAL_MERGES, totalMerges);
        editor.putInt(STATS_HIGHEST_TILE, highestTile);
        editor.putInt(STATS_OBJECTIVE_REACHED_COUNT, numberOfTimesObjectiveReached);
        editor.putInt(STATS_PERFECT_GAMES, perfectGames);
        editor.putLong(STATS_BEST_WINNING_TIME_MS, bestWinningTimeMs);
        editor.putLong(STATS_WORST_WINNING_TIME_MS, worstWinningTimeMs);
        editor.putInt(STATS_MP_GAMES_WON, multiplayerGamesWon);
        editor.putInt(STATS_MP_GAMES_PLAYED, multiplayerGamesPlayed);
        editor.putInt(STATS_MP_BEST_WINNING_STREAK, multiplayerBestWinningStreak);
        editor.putLong(STATS_MP_TOTAL_SCORE, multiplayerTotalScore);
        editor.putLong(STATS_MP_TOTAL_TIME_MS, multiplayerTotalTimeMs);
        editor.putInt(STATS_MP_LOSSES, totalMultiplayerLosses);
        editor.putInt(STATS_MP_HIGH_SCORE, multiplayerHighestScore);

        editor.apply(); // Applique les changements de manière asynchrone
    }

    // --- Méthodes de Mise à Jour des Statistiques ---

    /**
     * Doit être appelée au début de chaque nouvelle partie.
     * Incrémente le compteur de parties démarrées et réinitialise les stats de la partie en cours.
     */
    public void startGame() {
        totalGamesStarted++;
        currentMoves = 0;
        mergesThisGame = 0;
        currentGameStartTimeMs = System.currentTimeMillis();
    }

    /**
     * Enregistre un mouvement réussi (qui a modifié le plateau).
     */
    public void recordMove() {
        currentMoves++;
        totalMoves++;
    }

    /**
     * Enregistre une ou plusieurs fusions survenues lors d'un mouvement.
     * @param numberOfMerges Le nombre de fusions (si connu, sinon 1 par défaut).
     */
    public void recordMerge(int numberOfMerges) {
        if (numberOfMerges > 0) {
            mergesThisGame += numberOfMerges;
            totalMerges += numberOfMerges;
        }
    }

    /**
     * Met à jour la statistique de la plus haute tuile atteinte globalement.
     * @param tileValue La valeur de la tuile la plus haute de la partie en cours.
     */
    public void updateHighestTile(int tileValue) {
        if (tileValue > this.highestTile) {
            this.highestTile = tileValue;
        }
    }

    /**
     * Enregistre une victoire et met à jour les temps associés.
     * @param timeTakenMs Temps écoulé pour cette partie gagnante.
     */
    public void recordWin(long timeTakenMs) {
        numberOfTimesObjectiveReached++;
        if (timeTakenMs < bestWinningTimeMs) { bestWinningTimeMs = timeTakenMs; }
        if (timeTakenMs > worstWinningTimeMs) { worstWinningTimeMs = timeTakenMs; }
        endGame(timeTakenMs); // Finalise aussi le temps total et parties jouées
    }

    /**
     * Enregistre une défaite.
     */
    public void recordLoss() {
        // Calcule le temps écoulé avant de finaliser
        endGame(System.currentTimeMillis() - currentGameStartTimeMs);
    }

    /**
     * Finalise les statistiques générales à la fin d'une partie (victoire ou défaite).
     * @param timeTakenMs Temps total de la partie terminée.
     */
    public void endGame(long timeTakenMs) {
        totalGamesPlayed++;
        addPlayTime(timeTakenMs);
    }

    /**
     * Ajoute une durée (en ms) au temps de jeu total enregistré.
     * Typiquement appelé dans `onPause`.
     * @param durationMs Durée à ajouter.
     */
    public void addPlayTime(long durationMs) {
        if (durationMs > 0) {
            this.totalPlayTimeMs += durationMs;
        }
    }

    /**
     * Réinitialise toutes les statistiques (solo, multijoueur, high score global)
     * à leurs valeurs par défaut.
     */
    public void resetStats() {
        // Réinitialise toutes les variables membres à 0 ou valeur initiale
        overallHighScore = 0;
        totalGamesPlayed = 0;
        totalGamesStarted = 0;
        totalMoves = 0;
        totalPlayTimeMs = 0;
        totalMerges = 0;
        highestTile = 0;
        numberOfTimesObjectiveReached = 0;
        perfectGames = 0;
        bestWinningTimeMs = Long.MAX_VALUE;
        worstWinningTimeMs = 0;

        multiplayerGamesWon = 0;
        multiplayerGamesPlayed = 0;
        multiplayerBestWinningStreak = 0;
        multiplayerTotalScore = 0;
        multiplayerTotalTimeMs = 0;
        totalMultiplayerLosses = 0;
        multiplayerHighestScore = 0;

        saveStats();
    }

    // --- Getters pour l'affichage ---
    public int getTotalGamesPlayed() { return totalGamesPlayed; }
    public int getTotalGamesStarted() { return totalGamesStarted; }
    public int getTotalMoves() { return totalMoves; }
    public int getCurrentMoves() { return currentMoves; }
    public long getTotalPlayTimeMs() { return totalPlayTimeMs; }
    public long getCurrentGameStartTimeMs() { return currentGameStartTimeMs; } // Utile pour calcul durée en cours
    public int getMergesThisGame() { return mergesThisGame; }
    public int getTotalMerges() { return totalMerges; }
    public int getHighestTile() { return highestTile; }
    public int getNumberOfTimesObjectiveReached() { return numberOfTimesObjectiveReached; }
    public int getPerfectGames() { return perfectGames; }
    public long getBestWinningTimeMs() { return bestWinningTimeMs; }
    public long getWorstWinningTimeMs() { return worstWinningTimeMs; }
    public int getOverallHighScore() { return overallHighScore; } // Getter pour HS global
    // Getters Multiplayer
    public int getMultiplayerGamesWon() { return multiplayerGamesWon; }
    public int getMultiplayerGamesPlayed() { return multiplayerGamesPlayed; }
    public int getMultiplayerBestWinningStreak() { return multiplayerBestWinningStreak; }
    public long getMultiplayerTotalScore() { return multiplayerTotalScore; }
    public long getMultiplayerTotalTimeMs() { return multiplayerTotalTimeMs; }
    public int getTotalMultiplayerLosses() { return totalMultiplayerLosses; }
    public int getMultiplayerHighestScore() { return multiplayerHighestScore; }

    // --- Setters ---
    /** Met à jour la valeur interne du high score global. */
    public void setHighestScore(int highScore) {
        // Met à jour si la nouvelle valeur est meilleure
        if (highScore > this.overallHighScore) {
            this.overallHighScore = highScore;
            // La sauvegarde se fait via saveStats() globalement
        }
    }
    /** Définit le timestamp de début de la partie en cours. */
    public void setCurrentGameStartTimeMs(long timeMs) { this.currentGameStartTimeMs = timeMs; }

    // --- Méthodes Calculées ---
    /** @return Temps moyen par partie terminée en millisecondes. */
    public long getAverageGameTimeMs() { return (totalGamesPlayed > 0) ? totalPlayTimeMs / totalGamesPlayed : 0; }
    /** @return Score moyen par partie multijoueur terminée. */
    public int getMultiplayerAverageScore() { return (multiplayerGamesPlayed > 0) ? (int)(multiplayerTotalScore / multiplayerGamesPlayed) : 0; }
    /** @return Temps moyen par partie multijoueur terminée en millisecondes. */
    public long getMultiplayerAverageTimeMs() { return (multiplayerGamesPlayed > 0) ? multiplayerTotalTimeMs / multiplayerGamesPlayed : 0; }

    /**
     * Formate une durée en millisecondes en chaîne "hh:mm:ss" ou "mm:ss".
     * @param milliseconds Durée en millisecondes.
     * @return Chaîne de temps formatée.
     */
    @SuppressLint("DefaultLocale")
    public static String formatTime(long milliseconds) {
        long hours = TimeUnit.MILLISECONDS.toHours(milliseconds);
        long minutes = TimeUnit.MILLISECONDS.toMinutes(milliseconds) % 60;
        long seconds = TimeUnit.MILLISECONDS.toSeconds(milliseconds) % 60;
        if (hours > 0) { return String.format("%02d:%02d:%02d", hours, minutes, seconds); }
        else { return String.format("%02d:%02d", minutes, seconds); }
    }
}