// Fichier NotificationHelper.java
package legion.muyue.best2048;

import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.os.Build;
import androidx.core.app.NotificationCompat;
import androidx.core.app.NotificationManagerCompat;
import androidx.core.content.ContextCompat; // Pour checkSelfPermission

/**
 * Classe utilitaire pour simplifier la création et l'affichage des notifications
 * et la gestion du canal de notification pour l'application Best 2048.
 */
public class NotificationHelper {

    /** Identifiant unique du canal de notification pour cette application. */
    public static final String CHANNEL_ID = "BEST_2048_CHANNEL"; // Doit correspondre à celui utilisé avant

    /**
     * Crée le canal de notification requis pour Android 8.0 (API 26) et supérieur.
     * Cette méthode est idempotente (l'appeler plusieurs fois n'a pas d'effet négatif).
     * Doit être appelée avant d'afficher la première notification sur API 26+.
     *
     * @param context Contexte applicatif.
     */
    public static void createNotificationChannel(Context context) {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            CharSequence name = context.getString(R.string.notification_channel_name);
            String description = context.getString(R.string.notification_channel_description);
            int importance = NotificationManager.IMPORTANCE_DEFAULT; // Importance par défaut

            NotificationChannel channel = new NotificationChannel(CHANNEL_ID, name, importance);
            channel.setDescription(description);
            // Enregistre le canal auprès du système.
            NotificationManager notificationManager = context.getSystemService(NotificationManager.class);
            if (notificationManager != null) {
                notificationManager.createNotificationChannel(channel);
            }
        }
    }

    /**
     * Construit et affiche une notification.
     * Vérifie la permission POST_NOTIFICATIONS sur Android 13+ avant d'essayer d'afficher.
     *
     * @param context Contexte (peut être une Activity ou un Service).
     * @param title Titre de la notification.
     * @param message Contenu texte de la notification.
     * @param notificationId ID unique pour cette notification (permet de la mettre à jour ou l'annuler).
     */
    public static void showNotification(Context context, String title, String message, int notificationId) {
        // Vérification de la permission pour Android 13+
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.TIRAMISU) {
            if (ContextCompat.checkSelfPermission(context, android.Manifest.permission.POST_NOTIFICATIONS) != android.content.pm.PackageManager.PERMISSION_GRANTED) {
                // Si la permission n'est pas accordée, ne pas tenter d'afficher la notification.
                // L'application devrait idéalement gérer la demande de permission avant d'appeler cette méthode
                // si elle sait que l'utilisateur a activé les notifications dans les paramètres.
                System.err.println("Permission POST_NOTIFICATIONS manquante. Notification non affichée.");
                return;
            }
        }

        // Intent pour ouvrir MainActivity au clic
        Intent intent = new Intent(context, MainActivity.class);
        intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_CLEAR_TASK);
        int flags = (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) ? PendingIntent.FLAG_UPDATE_CURRENT | PendingIntent.FLAG_IMMUTABLE : PendingIntent.FLAG_UPDATE_CURRENT;
        PendingIntent pendingIntent = PendingIntent.getActivity(context, 0, intent, flags);

        // Construction de la notification via NotificationCompat pour la compatibilité
        NotificationCompat.Builder builder = new NotificationCompat.Builder(context, CHANNEL_ID)
                .setSmallIcon(R.drawable.ic_stat_notification_2048) // Votre icône de notification
                .setContentTitle(title)
                .setContentText(message)
                .setPriority(NotificationCompat.PRIORITY_DEFAULT) // Priorité normale
                .setContentIntent(pendingIntent) // Action au clic
                .setAutoCancel(true); // Ferme la notification après le clic

        // Affichage de la notification
        NotificationManagerCompat notificationManager = NotificationManagerCompat.from(context);
        try {
            notificationManager.notify(notificationId, builder.build());
        } catch (SecurityException e){
            // Gérer l'exception de sécurité qui peut survenir même avec la vérification ci-dessus dans certains cas limites
            System.err.println("Erreur de sécurité lors de l'affichage de la notification : " + e.getMessage());
        }
    }
}