// Fichier NotificationService.java
package legion.muyue.best2048;

import android.app.Service;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Handler;
import android.os.IBinder;
import android.os.Looper; // Important pour créer un Handler sur le Main Thread
import androidx.annotation.Nullable;
import java.util.concurrent.TimeUnit;

/**
 * Service exécuté en arrière-plan pour envoyer des notifications périodiques
 * (rappel de meilleur score, rappel d'inactivité).
 * Utilise un Handler pour planifier les tâches répétitives.
 * NOTE : Pour une robustesse accrue (garantie d'exécution même si l'app est tuée),
 * WorkManager serait préférable en production.
 */
public class NotificationService extends Service {

    private static final int NOTIFICATION_ID_HIGHSCORE = 2; // Doit être différent des autres notifs
    private static final int NOTIFICATION_ID_INACTIVITY = 3;
    // Intervalles (exemples : 1 jour pour HS, 3 jours pour inactivité)
    private static final long HIGHSCORE_INTERVAL_MS = TimeUnit.DAYS.toMillis(1);
    private static final long INACTIVITY_INTERVAL_MS = TimeUnit.DAYS.toMillis(3);
    private static final long CHECK_INTERVAL_MS = TimeUnit.HOURS.toMillis(6); // Intervalle de vérification plus fréquent

    private Handler handler;
    private Runnable periodicTaskRunnable;

    // Clés SharedPreferences (doivent correspondre à celles utilisées ailleurs)
    private static final String PREFS_NAME = "Best2048_Prefs";
    private static final String HIGH_SCORE_KEY = "high_score";
    private static final String LAST_PLAYED_TIME_KEY = "last_played_time"; // Nouvelle clé

    @Override
    public void onCreate() {
        super.onCreate();
        // Utilise le Looper principal pour le Handler (simple, mais bloque si tâche longue)
        // Pour des tâches plus lourdes, utiliser HandlerThread
        handler = new Handler(Looper.getMainLooper());
        // Pas besoin de créer le canal ici si MainActivity le fait déjà au démarrage
        // NotificationHelper.createNotificationChannel(this);

        periodicTaskRunnable = new Runnable() {
            @Override
            public void run() {
                // Vérifie périodiquement s'il faut envoyer une notification
                checkAndSendNotifications();
                // Replanifie la tâche
                handler.postDelayed(this, CHECK_INTERVAL_MS); // Vérifie toutes les X heures
            }
        };
    }

    @Override
    public int onStartCommand(Intent intent, int flags, int startId) {
        // Lance la tâche périodique lors du démarrage du service
        handler.removeCallbacks(periodicTaskRunnable); // Assure qu'il n'y a pas de doublon
        handler.post(periodicTaskRunnable); // Lance immédiatement la première vérification

        // START_STICKY : Le système essaiera de recréer le service s'il est tué.
        return START_STICKY;
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        // Arrête la planification des tâches lorsque le service est détruit
        if (handler != null && periodicTaskRunnable != null) {
            handler.removeCallbacks(periodicTaskRunnable);
        }
    }

    @Nullable
    @Override
    public IBinder onBind(Intent intent) {
        // Service non lié (Started Service)
        return null;
    }

    /**
     * Vérifie les conditions et envoie les notifications périodiques si nécessaire.
     */
    private void checkAndSendNotifications() {
        SharedPreferences prefs = getSharedPreferences(PREFS_NAME, MODE_PRIVATE);
        boolean notificationsEnabled = prefs.getBoolean("notifications_enabled", true); // Vérifie si activé

        if (!notificationsEnabled) {
            // Si désactivé dans les prefs, on arrête potentiellement le service?
            // Ou juste ne rien envoyer. Pour l'instant, ne rien envoyer.
            // stopSelf(); // Arrêterait le service
            return;
        }

        // --- Notification High Score (Exemple: envoyer une fois par jour si non joué depuis ?) ---
        // Logique simplifiée: on envoie juste le rappel basé sur un flag ou temps (pas implémenté ici)
        // Pour une vraie app, il faudrait une logique pour ne pas spammer.
        // Exemple: Envoyer si le dernier envoi date de plus de HIGHSCORE_INTERVAL_MS ?
        int highScore = prefs.getInt(HIGH_SCORE_KEY, 0);
        // Temporairement on l'envoie à chaque check pour test (à modifier!)
        // if (shouldSendHighScoreNotification()) {
        showHighScoreNotificationNow(highScore);
        // }


        // --- Notification d'Inactivité ---
        long lastPlayedTime = prefs.getLong(LAST_PLAYED_TIME_KEY, 0);
        if (lastPlayedTime > 0 && (System.currentTimeMillis() - lastPlayedTime > INACTIVITY_INTERVAL_MS)) {
            // Si l'inactivité dépasse le seuil
            showInactivityNotificationNow();
            // Optionnel: Mettre à jour lastPlayedTime pour ne pas renvoyer immédiatement ?
            // Ou attendre que l'utilisateur rejoue pour mettre à jour lastPlayedTime dans onPause.
        }
    }

    /** Affiche la notification High Score */
    private void showHighScoreNotificationNow(int highScore) {
        String title = getString(R.string.notification_title_highscore);
        String message = getString(R.string.notification_text_highscore, highScore);
        NotificationHelper.showNotification(this, title, message, NOTIFICATION_ID_HIGHSCORE);
    }

    /** Affiche la notification d'Inactivité */
    private void showInactivityNotificationNow() {
        String title = getString(R.string.notification_title_inactivity);
        String message = getString(R.string.notification_text_inactivity);
        NotificationHelper.showNotification(this, title, message, NOTIFICATION_ID_INACTIVITY);
    }

    // Ajouter ici une logique plus fine si nécessaire pour savoir QUAND envoyer les notifs périodiques
    // private boolean shouldSendHighScoreNotification() { ... }

}